import { OpCode } from "../../OpCode.js";
import { UnknownWallet } from "../../wallets/UnknownWallet.js";
import { Action } from "./Action.js";
import { ActionType } from "./ActionType.js";
export class JettonTransferAction extends Action {
    get type() {
        return this._type;
    }
    get amount() {
        return this._amount;
    }
    get destination() {
        return this._destination;
    }
    get response_destination() {
        return this._response_destination;
    }
    get query_id() {
        return this._query_id;
    }
    static fromCell(cell) {
        const slice = cell.beginParse();
        const queryId = slice.loadUint(64);
        const amount = slice.loadCoins();
        const destination = slice.loadAddress();
        const respDestination = slice.loadAddress();
        const maybePayload = slice.loadBit();
        const payload = maybePayload ? slice.loadRef().beginParse() : slice;
        const payloadOp = payload.loadUint(32);
        let comment = "";
        if (payloadOp !== 0) {
            // Log.info("no text comment in transfer_notification");
        }
        else {
            const commentBody = payload.loadBuffer(payload.remainingBits / 8);
            const commentData = new TextDecoder().decode(commentBody);
            comment = commentData ? commentData : "";
        }
        const dest = new UnknownWallet(destination);
        let respDest = null;
        if (respDestination) {
            respDest = new UnknownWallet(respDestination);
        }
        return { action: new JettonTransferAction(amount, dest, respDest, queryId, cell), comment };
    }
    // tslint:disable-next-line:variable-name
    _amount;
    // tslint:disable-next-line:variable-name
    _destination;
    // tslint:disable-next-line:variable-name
    _response_destination;
    // tslint:disable-next-line:variable-name
    _query_id;
    // tslint:disable-next-line:variable-name
    constructor(amount, destination, responseDestination, queryId = 0, body) {
        super(ActionType.jetton_transfer, OpCode.jetton_transfer, body);
        this._amount = amount;
        this._destination = destination;
        this._response_destination = responseDestination;
        this._query_id = queryId;
    }
}
