import dotenv from "dotenv";
// Parsing the env file.
dotenv.config();
// Loading process.env as ENV interface
const getConfig = () => {
    return {
        TESTNET_API_KEY: process.env.TESTNET_API_KEY,
        MAINNET_API_KEY: process.env.MAINNET_API_KEY,
        DEBUG: process.env.DEBUG?.toLowerCase() === "true",
    };
};
// Throwing an Error if any field was undefined we don't
// want our app to run if it can't connect to DB and ensure
// that these fields are accessible. If all is good return
// it as Config which just removes the undefined from our type
// definition.
// tslint:disable-next-line:no-shadowed-variable
const getSanitzedConfig = (config) => {
    for (const [key, value] of Object.entries(config)) {
        if (value === undefined) {
            throw new Error(`Missing key ${key} in .env`);
        }
    }
    return config;
};
export const config = getConfig();
const sanitizedConfig = getSanitzedConfig(config);
export default sanitizedConfig;
